@@ -51,6 +51,15 @@ class Bindings(Configurable):
         # Set if exception support is enabled.
         Option('exceptions', option_type=bool),
 
+        # The list of extra compiler arguments.
+        Option('extra_compile_args', option_type=list),
+
+        # The list of extra linker arguments.
+        Option('extra_link_args', option_type=list),
+
+        # The list of extra compiled object files to link.
+        Option('extra_objects', option_type=list),
+
         # The list of extracts to generate.
         Option('generate_extracts', option_type=list),
 
@@ -144,7 +153,7 @@ class Bindings(Configurable):
         project = self.project
 
         # Parse the input file.
-        pt, fq_name, uses_limited_api, sip_files = parse(
+        pt, fq_name, uses_limited_api, sip_files, self.tags, self.disabled_features = parse(
                 self.sip_file.replace('\\', '/'), True, self.tags, None,
                 self.disabled_features, self.protected_is_public)
 
@@ -158,6 +167,10 @@ class Bindings(Configurable):
 
         buildable.builder_settings.extend(self.builder_settings)
         buildable.debug = self.debug
+        buildable.exceptions = self.exceptions
+        buildable.extra_compile_args = self.extra_compile_args
+        buildable.extra_link_args = self.extra_link_args
+        buildable.extra_objects = self.extra_objects
         buildable.static = self.static
 
         # Generate any API file.
@@ -191,8 +204,7 @@ class Bindings(Configurable):
         header, sources = generateCode(pt, buildable.build_dir,
                 self.source_suffix, self.exceptions, self.tracing,
                 self.release_gil, self.concatenate, self.tags,
-                self.disabled_features, self.docstrings, project.py_debug,
-                project.sip_module)
+                self.disabled_features, self.docstrings, project.py_debug)
 
         if header:
             buildable.headers.append(header)
@@ -273,6 +285,8 @@ class Bindings(Configurable):
         super().verify_configuration(tool)
 
         # Make sure relevent paths are absolute and use native separators.
+        self.extra_objects = [project.project_path(o)
+                for o in self.extra_objects]
         self.headers = [project.project_path(h) for h in self.headers]
         self.include_dirs = [project.project_path(d)
                 for d in self.include_dirs]
